ZenFeed
=======

Zen feed reader − inspired by zencancan.

Documentation is available at <http://fspot.github.io/zenfeed/>.


Screenshots
-----------

Feed list :

![feed_list](https://cdn.mediacru.sh/85fg1zEf8fQR.png)

Feed view :

![feed_view](https://cdn.mediacru.sh/pX8d2iWXpHI6.png)

Article view :

![article_view](https://cdn.mediacru.sh/3iiUrJfCRFql.png)

Layout on smartphones :

![layout_mobile](https://cdn.mediacru.sh/2qFVC52hgB6X.png)



Todo
----

- add import/export OPML feature
- test zenfeed with mysql and postgresql
- actually remove oldest entries when threshold is exceeded
